%% AnalyzeSimulatedData

% Objective: To analyze the output binary files from PileResponse.m
% Method: Gumbel analysis

% Last Modified: 05.2015
% Authors: Loup and Joakim
%%
folderpath = '/Volumes/MacintoshHD1/RunsOrganized/Irregular_Hs9.04_Tp11.25_h30/';
include_Cs = 1;
models = cell(1);
legend_text = cell(1);
if include_Cs == 0;
    models(1) = cellstr('calc_Morison_deep_with_Wheeler/');legend_text(1)=cellstr('Morison w/ Wheeler str., deep water');
    models(2) = cellstr('calc_Morison_deep_with_Wheeler_2damping/');legend_text(2)=cellstr('Morison w/ Wheeler str., deep water, double damping');
    models(3) = cellstr('calc_Morison_finite_with_Wheeler/');legend_text(3)=cellstr('Morison w/ Wheeler str., finite depth');
elseif include_Cs == 1;
    models(1) = cellstr('calc_Morison_slam_deep_with_Wheeler/');legend_text(1)=cellstr('Morison w/ Wheeler str., deep water');
    models(2) = cellstr('calc_Morison_slam_deep_with_Wheeler_2damping/');legend_text(2)=cellstr('Morison w/ Wheeler str., deep water, double damping');
    models(3) = cellstr('calc_Morison_slam_finite_with_Wheeler/');legend_text(3)=cellstr('Morison w/ Wheeler str., finite depth');
end    
models(4) = cellstr('calc_FNV_finite/');legend_text(4)=cellstr('FNV, finite depth');
models(5) = cellstr('calc_FNV_deep/');legend_text(5)=cellstr('FNV, deep water');
models(6) = cellstr('calc_FNV_deep_2damping/');legend_text(6)=cellstr('FNV, deep water, double damping');
legend_text(end+1) = cellstr('Measured data');

CC = strsplit(folderpath,'/');
CCC = strsplit(cell2mat(CC(5)),'_');
name = [cell2mat(CCC(2)) 'm, '  cell2mat(CCC(3)) 's, ' cell2mat(CCC(4)) 'm'];
files = [13];

tot_max_moments = zeros(length(models)+1,length(files));
tot_gumbel_data = zeros(length(models)+1,3);

K = 3400; % rotational stiffness

quantile = .95;    

% Calculating Gumbel data for all models
for j = 1:length(models)
    model = cell2mat(models(j));
    log_path = [folderpath,model,'log.txt'];
    
    max_moments = zeros(1,length(files));


    for k = files
        fileID = fopen(log_path);
        C = textscan(fileID,'%s %s %s %s','HeaderLines',1,'Delimiter',',');
        fclose(fileID);
        output_path = [folderpath (C{2}{k})];
        numerical_path = [folderpath,model,(C{4}{k})];
        
        fID_num = fopen(numerical_path);
        data_num = fread(fID_num,[6,Inf],'double');
        t_num = data_num(1,:);
        theta_num = data_num(end,:);
        M_num_res = theta_num * K; % responding moment
        
        max_moments(k) = max(abs(M_num_res));

    end

    tot_max_moments(j,:) = max_moments;
    [x,p1,p2] = GumbelAnalyze(max_moments,quantile);
    tot_gumbel_data(j,:) = ([x,p1,p2]);

end

% Calculating Gumbel data for measured data
for k = files
    fileID = fopen([folderpath,'log.txt']);
    C_log = textscan(fileID,'%s %s','HeaderLines',2,'Delimiter',',');
    fclose(fileID);
    output_path = [folderpath '/' cell2mat(C_log{2}(k)) '.bin'];
    [~,b] = catman_read(output_path);
    M_meas = b(37).data(:);
    M_meas = M_meas-mean(M_meas(1:2000));
    
    max_moments(k) = max(abs(M_meas));
    
    
end

tot_max_moments(end,:) = max_moments;
[x,p1,p2] = GumbelAnalyze(max_moments,quantile);
tot_gumbel_data(end,:) = ([x,p1,p2]);

s = length(files)+1;
X_prob = 1/s:1/s:1-1/s;

colors = cell(1);
colors(1) = cellstr('r');
colors(2) = cellstr('b');
colors(3) = cellstr('g');
colors(4) = cellstr('m');
colors(5) = cellstr('c');
colors(6) = cellstr('y');
figure;
hold on;

pl = [];
% Plotting results for the different models
for j = 1:length(models)
    color = cell2mat(colors(j));
   vec_max = sort(tot_max_moments(j,:));
   pl = [pl,plot(vec_max,-log(-log(X_prob)),[color,'o'])];
   p1 = tot_gumbel_data(j,2);
   p2 = tot_gumbel_data(j,3);
   
   pl = [pl,plot([vec_max(1) vec_max(end)],[p1*vec_max(1) + p2 p1*vec_max(end) + p2],color)];
   
end

% Plotting measured values
vec_max = sort(tot_max_moments(end,:));
pl = [pl,plot(vec_max,-log(-log(X_prob)),'ks','MarkerFaceColor','k')];%'Marker','s')];
p1 = tot_gumbel_data(end,2);
p2 = tot_gumbel_data(end,3);
pl = [pl,plot([vec_max(1) vec_max(end)],[p1*vec_max(1) + p2 p1*vec_max(end) + p2],'k')];

legend(pl(2:2:end),legend_text)
xlabel('Maximum moment [Nm]');
ylabel('log(log(F))');
title(name)

fig_name = ['/Volumes/MacintoshHD1/RunsOrganized/Irregular_Hs8.22_Tp15_h30/' name '.fig'];
savefig(fig_name);