%% CalcHsTpProbability

% Objective: To establish sea state probabilities for the Dogger Bank, 
% Creyke Beck B, location 2

% Method: Using the values and formulae of [Mathiesen et al., 2014]
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   hs          double [m]          significant wave height
%   tp          double [s]          peak period

%   Output      Type/Dimension      Description
%   p           double [-]          probability of sea state
%%
function [p] = CalcHsTpProbability(hs,tp)

eta = 2.802;
alpha = 0.591;
theta = 0.313;
beta = 1.315;
rho = 1.546;

if hs <= eta
    fhs = (1/(sqrt(2*pi)*alpha*hs)) * exp(-((log(hs)-theta).^2)/(2*alpha.^2));
else
    fhs = (beta/rho)*((hs/rho).^(beta-1))*exp(-(hs/rho).^beta);    
end

a1 = 0.889;
a2 = 0.913;
a3 = 0.3;
b1 = 0.005;
b2 = 0.123;
b3 = 0.486;

mu = a1 + a2*hs.^a3;
sigma = sqrt(b1 + b2*exp(-b3*hs));

ftphs = (1/(sqrt(2*pi)*sigma*tp)) * exp(-((log(tp)-mu).^2)/(2*sigma.^2));

p = fhs * ftphs;
end

