%% CheckHsTpFromInput

% Objective: Checking the nominal Hs, Tp values
% Method: Spectral analysis
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   filepath    char                specific seed file path
%   ramp        double [s]          ramp duration
%   duration    double [s]          sea state duration
%   lambda      double [-]          scaling factor

%   Output      Type/Dimension      Description
%   Hs          double [m]          nominal Hs
%   Tp          double [m]          nominal Tp
%   F	        vector [Hz]         frequency
%   Y	        vector              spectral values, wave elevation
%%
function [Hs,Tp,F,Y] = CheckHsTpFromInput(filepath,ramp,duration,lambda)

T = readtable(filepath);

t = table2array(T(:,1));
x = table2array(T(:,2));

dt = t(2)-t(1);

t(1:ramp/dt) = [];
x(1:ramp/dt) = [];

t = t - t(1);

t(duration/dt:end) = [];
x(duration/dt:end) = [];

Y = abs(fft(x))/length(x);
Y(floor(length(Y)/2):end) = [];
F = (.5/dt)*linspace(0,1,length(Y));

% finding the peak period from the peak of the spectrum
m = max(Y);
I = find(Y == m,1);
Tp = sqrt(lambda)/(F(I));

% measured significant wave height found from the standard deviation
Hs = 4*std(x)*lambda;

end

