%% CheckHsTpFromMeas

% Objective: Checking the effective Hs, Tp values
% Method: Spectral analysis
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   filepath    char                specific seed file path
%   ramp        double [s]          ramp duration
%   duration    double [s]          sea state duration
%   trigger_end double [s]          time to changing ts from 1 to 0
%   lambda      double [-]          scaling factor

%   Output      Type/Dimension      Description
%   Hs_meas     double [m]          effective Hs
%   Tp_meas     double [m]          effective Tp
%   dt          double [s]          time step
%%
function [Hs_meas,Tp_meas,dt] = CheckHsTpFromMeas(filepath,ramp,duration,trigger_end,lambda)

[a,b] = catman_read(filepath);

t_meas = b(1).data(:);
dt = t_meas(2) - t_meas(1);

x_meas1 = b(3).data(:);
x_meas = b(25).data(:);
x8 = x_meas;
flap_meas = b(2).data(:);

first_value =find(x_meas>2e-3,1);
x_meas (1:floor(first_value+ramp/dt)) = [];
t_meas (1:floor(first_value+ramp/dt)) = [];
t_meas = t_meas-t_meas(1);


x_meas (floor(duration/dt:end)) = [];
t_meas (floor(duration/dt:end)) = [];
 

Y = abs(fft(x_meas))/length(x_meas);
Y(1) = 0;
Y(floor(length(Y)/2):end) = [];
F = (1/(2*(t_meas(2)-t_meas(1))))*linspace(0,1,length(Y));

% finding the peak period from the peak of the spectrum
m = max(Y);
I = find(Y == m,1);
Tp_meas = sqrt(lambda)/(F(I));

% measured significant wave height found from the standard deviation
Hs_meas = 4*std(x_meas)*lambda;

end

