%% Compare

% Objective: Checking the nominal and effective Hs, Tp values
% Method: Spectral analysis
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   folderpath  char                sea state folder path
%   log_path    char                file log file path
%   output_path char                specific seed file path
%   ramp        double [s]          ramp duration
%   duration    double [s]          sea state duration
%   file        double [-]          for loop iteration
%   trigger_end double [s]          time to changing ts from 1 to 0
%   lambda      double [-]          scaling factor

%   Output      Type/Dimension      Description
%   Hs_in       double [m]          nominal Hs
%   Tp_in       double [m]          nominal Tp
%   Hs_meas     double [m]          effective Hs
%   Tp_meas     double [m]          effective Tp
%   dt_out      double [s]          time step
%   F_in        vector [Hz]         frequency
%   Y_in        vector              spectral values, wave elevation
%%
function [Hs_in,Tp_in,Hs_meas,Tp_meas,dt_out,F_in,Y_in] = Compare(folderpath,log_path,output_path,ramp,duration,file,trigger_end,lambda)

fileID = fopen(log_path);
C = textscan(fileID,'%s %s','HeaderLines',2,'Delimiter',',');

input_path = [folderpath cell2mat(C{1}(file))];

[Hs_meas,Tp_meas,dt_out] = CheckHsTpFromMeas(output_path,ramp,duration,trigger_end,lambda);
[Hs_in,Tp_in,F_in,Y_in] = CheckHsTpFromInput(input_path,ramp, duration,lambda);

end
