%%   CompareFMspectra

% Objective: To compare force and moment spectra (smoothed and unsmoothed) 
% for each seed of a sea state

% Method: Plotting the nominal and effective wave spectra

% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   freq        vector [Hz]         frequency vector
%   moment_tot  vector [Nm]         moment spectrum values
%   force_tot   vector [N]          shear force spectrum values
%   h           double [m]          water depth
%   files       vector [-]          vector of files (seeds) that are run
%   Tp_vec_meas vector [s]          vector of measured Tp values
%   Hs_specified vector [m]         vector of specified Hs values
%   Tp_specified vector [s]         vector of specified Tp values
%   lambda      double [-]          scaling factor
%%
function []=CompareFMspectra(freq,moment_tot,force_tot,h,files,Tp_vec_meas,Hs_specified,Tp_specified,lambda)

figure;
for k=files
    subplot(4,5,k)
    if h==30
        plot([1/3.94 1/3.94],[0 max(moment_tot(:,k))])
    elseif h==20.9
        plot([1/3.77 1/3.77],[0 max(moment_tot(:,k))])
    end
    hold on;
    plot([1/Tp_vec_meas(k) 1/Tp_vec_meas(k)],[0 max(moment_tot(:,k))])
    hold on;
    [AX,H1,H2] = plotyy(freq,moment_tot(:,k),freq,force_tot(:,k));
    xlim(AX(1),[0 0.43])
    xlim(AX(2),[0 0.43])
    xlabel('f [Hz]')
end
legend('Eigenfrequency','fp measured','Moment spectra','Force spectra')
graphtitle1=['Comparing moment and force spectra for specified H_s = ' num2str(Hs_specified(1)) ' m, specified T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
suptitle(graphtitle1);

figure;
for k=files
    subplot(4,5,k)
    if h==30
        plot([1/3.94 1/3.94],[0 max(moment_tot(:,k))])
    elseif h==20.9
        plot([1/3.77 1/3.77],[0 max(moment_tot(:,k))])
    end
    hold on;
    plot([1/Tp_vec_meas(k) 1/Tp_vec_meas(k)],[0 max(moment_tot(:,k))])
    hold on;
    [AX,H1,H2] = plotyy(freq,smooth(smooth(moment_tot(:,k))),freq,smooth(smooth(force_tot(:,k))));
    xlim(AX(1),[0 0.43])
    xlim(AX(2),[0 0.43])
    xlabel('f [Hz]')
end
legend('Eigenfrequency','fp measured','Smoothed moment spectra','Smoothed force spectra')
graphtitle2=['Comparing smoothed moment and force spectra for specified H_s = ' num2str(Hs_specified(1)) ' m, specified T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
suptitle(graphtitle2);

end