%% CompareFiles

% Objective: Post-processing irregular wave data
% Method: Spectral analyses and stochastic Gumbel analyses
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input
%   9000_output#.bin
%%
% INPUT
%folderpath = '/Volumes/MacintoshHD1/RunsOrganized/Irregular_Hs9.04_Tp11.25_h30/';
files = 1:20;   %specify which seeds you would like to analyze
lambda=48;  %scaling factor
duration = 3*3600/sqrt(lambda); %sea state duration
trigger_end = 120;  %[s]
tank_length=24; %[m]
tank_width=2.5; %[m]
g = 9.81; %gravitational acceleration [m/s^2]

Hs_vec_in = zeros(length(files),1);
Tp_vec_in = zeros(length(files),1);
Hs_vec_meas = zeros(length(files),1);
Tp_vec_meas = zeros(length(files),1);
seed_vec = zeros(length(files),1);
max_moment = [];
max_force = [];
output_names_vec = {};

log_path = [folderpath 'log.txt'];
fileID = fopen(log_path);
R=textscan(fileID,'%s %f',1,'HeaderLines',1,'Delimiter','=');
fclose(fileID);
ramp = R{2}(1);

x95F = [];
x05F = [];
x95M = [];
x05M = [];
wave_spectrum = [];
moment_spectrum = [];
force_spectrum = [];
F_in_vec=[];
Y_in_vec=[];
Hs_specified=[];
Tp_specified=[];

for k= files

    fileID = fopen(log_path);
    C = textscan(fileID,'%s %s','HeaderLines',2,'Delimiter',',');
    fclose(fileID);
    output_path = [folderpath cell2mat(C{2}(k)) '.bin'];
    output_names_vec(k) = (C{2}(k));
    
    % Finding the nominal and effective Hs, Tp values
    [Hs_vec_in(k), Tp_vec_in(k), Hs_vec_meas(k), Tp_vec_meas(k),dt_out,F_in,Y_in] = Compare(folderpath,log_path,output_path,ramp,floor(duration),k,trigger_end,lambda); 
    
    F_in = F_in/sqrt(lambda);
    Y_in = Y_in*lambda;
    
    input_file = cell2mat(C{1}(k));
    CC = strsplit(input_file,'_');
    seed = CC(5);
    seed_vec(k) = str2double(seed);
    
    % Reading the specified Hs, Tp values
    Hs_spec=cell2mat(CC(3));
    Hs_spec(end) = [];
    Hs_specified(k)=str2double(Hs_spec);
    Tp_spec=cell2mat(CC(4));
    Tp_spec(end) = [];
    Tp_specified(k)=str2double(Tp_spec);
    h=cell2mat(CC(6));
    h(end-3:end)=[];
    h(1)=[];
    h=str2double(h);

    % Reading measured data
    [a,b] = catman_read(output_path);
    W_elev=b(25).data(:);
    W_elev=W_elev-mean(W_elev(1:2000));
    first_step=find(abs(W_elev)>Hs_specified(k)/2500,1);
    F = b(36).data(:);
    F = F-mean(F(1:2000));
    F = CutTime(F,first_step,ramp/dt_out,floor(duration/dt_out));
    M = b(37).data(:);
    M = M-mean(M(1:2000));
    M = CutTime(M,first_step,ramp/dt_out,floor(duration/dt_out));
    accx = CutTime(b(32).data(:),first_step,ramp/dt_out,floor(duration/dt_out));
    W_elev = CutTime(W_elev,first_step,ramp/dt_out,floor(duration/dt_out));
    
    % Scaling the measured data
    W_elev = W_elev*lambda;
    F = F*lambda^3;
    M = M*lambda^4;
    dt_out = dt_out*sqrt(lambda);
    t = (dt_out:dt_out:dt_out*length(F))*.999717; %the .999717 factor is compensation for the measurement time axis being stretched
    
    max_moment = [max_moment;max(abs(M))];
    max_force = [max_force;max(abs(F))];

    % Gumbel analysis
    x95F= [x95F;Gumbel(max_force,.95)];
    x05F = [x05F;Gumbel(max_force,.05)];
    x95M= [x95M;Gumbel(max_moment,.95)];
    x05M = [x05M;Gumbel(max_moment,.05)];
    
    freq = (1/dt_out)*linspace(0,1,length(t));
    F_in_vec(:,k) = F_in;
    Y_in_vec(:,k) = Y_in;
    
    wave_spectrum(:,k) = zeros(length(t),1);
    moment_spectrum(:,k) = zeros(length(t),1);
    force_spectrum(:,k) = zeros(length(t),1);
    wave_spectrum(:,k) = abs(fft(W_elev))/length(W_elev);
    force_spectrum(:,k) = abs(fft(F))/length(F);
    moment_spectrum(:,k) = abs(fft(M))/length(M);
end

% seed-averaged spectra
wave_spectrum_ave = mean(wave_spectrum,2);
force_spectrum_ave = mean(force_spectrum,2);
moment_spectrum_ave = mean(moment_spectrum,2);

% writing out data to screen
Mean_MaxForce = mean(max_force)
Max_MaxForce = max(max_force)
Mean_MaxMoment = mean(max_moment)
Max_MaxMoment = max(max_moment)
Mean_HsMeas = mean(Hs_vec_meas);
Mean_TpMeas = mean(Tp_vec_meas);

% applying a 5th-order butterworth filter on the moment time series
if h==30
    eigenfreq=1/3.94;
elseif h==20.9
    eigenfreq=1/3.77;
end
% specifying the cut-off frequency as the mean of the peak frequency and
% the eigenfrequency
filtercutoff=(eigenfreq+1/Tp_vec_meas(end))/2;
FilteringButterworth(t,M,lambda,filtercutoff)

% finding the sloshing periods
long_slosh_period = 2*pi/(sqrt(g*pi*tanh(pi*h/lambda/tank_length)/tank_length))*sqrt(lambda);
trans_slosh_period = 2*pi/(sqrt(g*pi*tanh(pi*h/lambda/tank_width)/tank_width))*sqrt(lambda);

% plotting the seed-averaged wave spectra
figure;
plot(freq,smooth(wave_spectrum_ave))
hold on;
plot([1/Tp_specified(1) 1/Tp_specified(1)],[0 max(wave_spectrum_ave)])
hold on;
plot([1/long_slosh_period 1/long_slosh_period],[0 max(wave_spectrum_ave)])
hold on;
plot([1/trans_slosh_period 1/trans_slosh_period],[0 max(wave_spectrum_ave)])
legend('Averaged wave spectrum','fp specified','longitudinal sloshing frequency','transverse sloshing frequency')
xlim([0 0.6])
xlabel('f [Hz]')
graphtitle1=[num2str(length(files)) '-seed averaged wave (w7) spectra for specified H_s = ' num2str(Hs_specified(1)) ' m, specified T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
suptitle(graphtitle1);

% plotting the seed-averaged force and moment spectra
figure;
[AX,H1,H2] = plotyy(freq,smooth(force_spectrum_ave),freq,smooth(moment_spectrum_ave));
hold on;
if h==30
    plot([1/3.94 1/3.94],[0 max(force_spectrum_ave)],'LineWidth',1.5)
elseif h==20.9
    plot([1/3.77 1/3.77],[0 max(force_spectrum_ave)],'LineWidth',1.5)
end
hold on;
plot([1/Tp_specified(1) 1/Tp_specified(1)],[0 max(force_spectrum_ave)],'LineWidth',2)
legend('Averaged force spectrum','Averaged moment spectrum','fp specified','Eigenfrequency')
xlim(AX(1),[0 0.5])
xlim(AX(2),[0 0.5])
xlabel('f [Hz]')
graphtitle2=[num2str(length(files)) '-seed averaged moment and force spectra for specified H_s = ' num2str(Hs_specified(1)) ' m, specified T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
suptitle(graphtitle2);

% Comparing the wave elevation, force and moment spectra for each seed
CompareSpectra(h,files,Hs_specified,Tp_specified,F_in_vec,Y_in_vec,freq,wave_spectrum);
CompareFMspectra(freq,moment_spectrum,force_spectrum,h,files,Tp_vec_meas,Hs_specified,Tp_specified,lambda)

% Defining a ratio for the effective and nominal Hs, Tp
Hs_percent = 100*(Hs_vec_in-Hs_vec_meas)./Hs_vec_in;
Tp_percent = 100*(Tp_vec_in-Tp_vec_meas)./Tp_vec_in;

output_names = cell2mat(output_names_vec');
Hs_specified=Hs_specified';
Tp_specified=Tp_specified';
T = table(output_names,Hs_specified,Tp_specified,Hs_vec_in,Tp_vec_in,Hs_vec_meas,Tp_vec_meas,Hs_percent,Tp_percent,max_force,max_moment,seed_vec)

data=[Hs_vec_in Tp_vec_in Hs_vec_meas Tp_vec_meas Hs_percent Tp_percent max_force/10^6 max_moment/10^6 seed_vec];
%Automatizing the LaTeX tables
%columnLabels = {'\begin{tabular}[c]{@{}c@{}}H\textsubscript{s}\\wm input [m]\end{tabular}' '\begin{tabular}[c]{@{}c@{}}T\textsubscript{p}\\wm input [s]\end{tabular}' '\begin{tabular}[c]{@{}c@{}}H\textsubscript{s}\\measured [m]\end{tabular}' '\begin{tabular}[c]{@{}c@{}}T\textsubscript{p}\\measured [s]\end{tabular}' '\begin{tabular}[c]{@{}c@{}}\% H\textsubscript{s}\\achieved\end{tabular}' '\begin{tabular}[c]{@{}c@{}}\% T\textsubscript{p}\\achieved\end{tabular}' '\begin{tabular}[c]{@{}c@{}}Maximum\\force [MN]\end{tabular}' '\begin{tabular}[c]{@{}c@{}}Maximum\\moment [MNm]\end{tabular}' '\begin{tabular}[c]{@{}c@{}}Seed\\ \#\end{tabular}'};
%latexpath = ['/Users/JoakimFrimann-Dahl/Desktop/LatexTables/Table_Irregular_h' num2str(h) 'Hs' num2str(Hs_specified(1)) 'Tp' num2str(Tp_specified(1))]
%matrix2latexIrreg(data, latexpath, 'columnLabels', columnLabels, 'alignment', 'c', 'format', '%-6.2f');

% Plotting the Hs, Tp for each seed
CompareHsTpPlot(h,files,Hs_specified,Tp_specified,Hs_vec_in,Tp_vec_in,Hs_vec_meas,Tp_vec_meas);

% Gumbel analysis
max_quantile_force = GumbelPlot(max_force,0.95,Mean_HsMeas,Mean_TpMeas,Hs_specified(1),Tp_specified(1),h,1);
max_quantile_moment = GumbelPlot(max_moment,0.95,Mean_HsMeas,Mean_TpMeas,Hs_specified(1),Tp_specified(1),h,2);

figConF=floor(rand*1000000);
figure(figConF);
plot(files,max_force,'ko');
hold on;
plot(files(2:end),x95F(2:end),files(2:end),x05F(2:end));
xlabel('Run');
ylabel('Force [N]');
legend('Maximum per run','95% quantile','5% quantile')
graphtitle=['Irregular, H_s = ' num2str(Hs_specified(1)) ' m, T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
title(graphtitle);
filepath = ['/Users/JoakimFrimann-Dahl/Documents/MATLAB/Figures/Gumbel/1ConfidenceHs' num2str(floor(Hs_specified(1)*100)) 'Tp' num2str(floor(Tp_specified(1)*100)) 'h' num2str(floor(h*10)) '.png'];
saveas(figConF,filepath)

figConM=floor(rand*1000000);
figure(figConM);
plot(files,max_moment,'ko');
hold on;
plot(files(2:end),x95M(2:end),files(2:end),x05M(2:end));
xlabel('Run');
ylabel('Moment [Nm]');
legend('Maximum per run','95% quantile','5% quantile')
graphtitle=['Irregular, H_s = ' num2str(Hs_specified(1)) ' m, T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
title(graphtitle);
filepath = ['/Users/JoakimFrimann-Dahl/Documents/MATLAB/Figures/Gumbel/2ConfidenceHs' num2str(floor(Hs_specified(1)*100)) 'Tp' num2str(floor(Tp_specified(1)*100)) 'h' num2str(floor(h*10)) '.png'];
saveas(figConM,filepath)

fclose('all');