%%   CompareHsTpPlot

% Objective: To compare the Hs, Tp values for each sea state seed
% Method: Plotting the specified nominal and effective Hs, Tp values
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   h           vector [m]          water depth
%   files       vector [-]          vector of files (seeds) that are run
%   Hs_specified vector [m]         vector of specified Hs values
%   Tp_specified vector [s]         vector of specified Tp values
%   Hs_vec_in   vector [m]          vector of nominal Hs values
%   Tp_vec_in   vector [s]          vector of nominal Tp values
%   Hs_vec_meas vector [m]          vector of effective Hs values
%   Tp_vec_meas vector [s]          vector of effective Tp values
%%
function []=CompareHsTpPlot(h,files,Hs_specified,Tp_specified,Hs_vec_in,Tp_vec_in,Hs_vec_meas,Tp_vec_meas)

figure;
plot([0 length(Hs_specified)],[Hs_specified(1) Hs_specified(1)])
hold on;
plot([0 length(Hs_specified)],[1.005*Hs_specified(1) 1.005*Hs_specified(1)],'--','LineWidth',0.5)
hold on;
plot([0 length(Hs_specified)],[0.97*Hs_specified(1) 0.97*Hs_specified(1)],'--','LineWidth',0.5)
hold on;
    plot(1:length(files),Hs_vec_in(1:length(files)),'-*r');
    hold on;
    plot(1:length(files),Hs_vec_meas(1:length(files)),'-ob');
    hold on;
xlim([1 length(Hs_specified)])
xl=xlabel('Run no.');
yl=ylabel('H_s [m]');
leg=legend('Hs specified','1.005*Hs specified','0.97*Hs specified','Hs input to wavemaker','Hs measured');
graphtitle1=['Irregular waves H_s comparison for specified H_s = ' num2str(Hs_specified(1)) ' m, specified T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
tit=title(graphtitle1);
set(xl,'FontSize',14);
set(yl,'FontSize',14);
set(leg,'FontSize',14);
set(tit,'FontSize',14);
hold off;

figure;
plot([0 length(Tp_specified)],[Tp_specified(1) Tp_specified(1)])
hold on
plot([0 length(Tp_specified)],[1.03*Tp_specified(1) 1.03*Tp_specified(1)],'--','LineWidth',0.5)
hold on
plot([0 length(Tp_specified)],[0.97*Tp_specified(1) 0.97*Tp_specified(1)],'--','LineWidth',0.5)
hold on;
    plot(1:length(Tp_specified),Tp_vec_in(1:length(Tp_specified)),'-*r');
    hold on;
    plot(1:length(Tp_specified),Tp_vec_meas(1:length(Tp_specified)),'-ob');
    hold on;
xlim([1 length(Tp_specified)])
xl=xlabel('Run no.');
yl=ylabel('T_p [m]');
leg=legend('Tp specified','1.03*Tp specified','0.97*Tp specified','Tp input to wavemaker','Tp measured');
graphtitle2=['Irregular waves T_p comparison for specified H_s = ' num2str(Hs_specified(1)) ' m, specified T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
tit=title(graphtitle2);
set(xl,'FontSize',14);
set(yl,'FontSize',14);
set(leg,'FontSize',14);
set(tit,'FontSize',14);
hold off;

end 