%%   CompareSpectra

% Objective: To compare wave spectra (smoothed and unsmoothed) for each
% seed of a sea state

% Method: Plotting the nominal and effective wave spectra

% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   h           vector [m]          water depth
%   files       vector [-]          vector of files (seeds) that are run
%   Hs_specified vector [m]         vector of specified Hs values
%   Tp_specified vector [s]         vector of specified Tp values
%   F_in_vec    vector [m]          frequency values
%   Y_in_vec    vector [s]          nominal wave spectrum values
%   freq        vector [m]          frequency vector
%   wave_tot    vector [s]          effective wave spectrum values
%%
function []=CompareSpectra(h,files,Hs_specified,Tp_specified,F_in_vec,Y_in_vec,freq,wave_tot)

figure;
for k=files
    subplot(4,5,k)
    plot(freq,wave_tot(:,k))
    hold on;
    plot(F_in_vec(:,k),Y_in_vec(:,k))
    xlim([0 0.72])
    xlabel('f [Hz]')
    ylabel('S [m^2s]')
end
legend('Output wave spectra','Input wave spectra')
graphtitle1=['Comparison of effective and nominal wave elevation spectra for specified H_s = ' num2str(Hs_specified(1)) ' m, specified T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
suptitle(graphtitle1);

figure;
for k=files
    subplot(4,5,k)
    plot(freq,smooth(wave_tot(:,k)))
    hold on;
    plot(F_in_vec(:,k),smooth(Y_in_vec(:,k)))
    xlim([0 0.72])
    xlabel('f [Hz]')
    ylabel('S [m^2s]')
end
legend('Output wave spectra','Input wave spectra')
graphtitle2=['Comparison of smoothed effective and nominal wave elevation spectra for specified H_s = ' num2str(Hs_specified(1)) ' m, specified T_p = ' num2str(Tp_specified(1)) ' s, h = ' num2str(h) ' m'];
suptitle(graphtitle2);