%% CreateBatch

% Objective: Generating the batch files for irregular waves
% Method: Using the wavemaker transfer functions, reading in the generated 
% irregular wave elevation time series

% Last Modified: 04.2015
% Authors: Loup and Joakim

%   Input
%   wave_elev_Hs_Tp_seed_h.txt

%   Output
%   run#.dat
%%
% INPUT
folderpath='/Users/JoakimFrimann-Dahl/Documents/MATLAB/Master_matlab/Data/TestZeta/'; %where the wave elevation .txt files are found
directory=dir(fullfile(folderpath)); 
lambda = 48;    %scaling factor
gain_factor = 1.03; %to compensate for flap area beeing smaller than channel area
last_saved_output_str = '9000_395'; %a new folder is created based on the name of the last run
last_saved_output = str2double(last_saved_output_str(6:8));
test = last_saved_output_str(1:4);

num_files = length(directory)-2; %the file '.' and '..' are not used
initial_zeros = 5; %time where both trigger and waves are 0 before the simulation (s)
trigger_start = 5; %the time when the trigger is started before the waves
trigger_end = 120; %duration of trigger still on after waves have finished
rest = 8*60; %resting time between 2 runs, in seconds
dt = 0.02;
rest_vec = zeros(rest/dt,1); 

new_folder_path = ['/Users/JoakimFrimann-Dahl/Documents/MATLAB/Master_matlab/Data/TestZeta2/' test '_' numToString100(last_saved_output+1)]; %where the batch is placed
[status,mess,messid] = mkdir(new_folder_path);
if (~isempty(mess))
   error(mess); 
end

% finds the water depth (file name has to be consistent)
in = strfind(directory(3).name,'h');
en = strfind(directory(3).name,'.txt');
h_str = directory(3).name(in+1:en-1);
h = str2num(h_str);

t_final = 0;
t_tot = [];

total_wave_serie = zeros(initial_zeros/dt,1);
ts = zeros(initial_zeros/dt,1);

total_wave_serie = [total_wave_serie;zeros(trigger_start/dt,1)];
ts = [ts;ones(trigger_start/dt,1)];

input_files = cell(1,num_files);
output_files = cell(1,num_files);



for j=3:length(directory)
    
    % checks that water depth is the same for all files    
    in = strfind(directory(j).name,'h');
    en = strfind(directory(j).name,'.txt');
    h_str = directory(j).name(in+1:en-1);
    h_check = str2num(h_str);
    if (h_check~=h)
        error('The water depth is not the same for all files');
    end

    filepath = [folderpath directory(j).name];
    copyfile(filepath,new_folder_path);
    T=readtable(filepath);
    t = table2array(T(:,1));
    wave_elev = table2array(T(:,2));

    total_wave_serie = [total_wave_serie;wave_elev;rest_vec];
    ts = [ts;ones(length(wave_elev),1);ones(trigger_end/dt,1);zeros((rest-trigger_start-trigger_end)/dt,1)];

    if(j~=length(directory))
        ts = [ts;ones(trigger_start/dt,1)];
    else
        ts = [ts;zeros(trigger_start/dt,1)];
    end

    if(t(2)-t(1) ~= dt)
       disp(['dt is not the same as specified in file ' directory(j).name]); 
    end
    
        
    
    % For writing the log
    input_files(j-2) = cellstr(directory(j).name);
    output_files(j-2) = cellstr([last_saved_output_str(1:4) '_' numToString100(last_saved_output+j-2)]);
end

if mod(length(total_wave_serie),2)==0
    Nfreq = round(length(total_wave_serie)/2);
else
    Nfreq = round(length(total_wave_serie)/2)-1;
end

Y = fft(total_wave_serie);
F = (1/(dt))*linspace(0,1,length(Y));
Y = Y(1:Nfreq+2);
F = F(1:Nfreq+2);
omega = 2*pi*F;
H = biesel(omega,h/lambda,0);
Sb = Y./H';

MTF = MechTF(omega);
S = Sb./MTF';

I = find(F>3,1);
S(I+1:end) = 0;

S=[S; conj(S(Nfreq-1:-1:2))];
s = real(ifft(S))*1000*gain_factor; %*1000 because the stroke should be given in [mm]
t_tot = dt:dt:length(s)*dt;
s(find(total_wave_serie==0)) = 0;

plot(t_tot,total_wave_serie*1000)
hold on;
plot(t_tot,s)
plot(t_tot,ts)

% Setting up the data matrix
 data=[s ts zeros(1,length(S))' zeros(1,length(S))' zeros(1,length(S))' zeros(1,length(S))'];
wm_input_file_path = [new_folder_path '/run' numToString100(last_saved_output+1)];
write2mcl(wm_input_file_path,data,dt)

% Writing the log
log = table(input_files',output_files','VariableNames',{'Input' 'Output'});
log_file_path = [new_folder_path '/log' numToString100(last_saved_output+1) '.txt'];
writetable(log,log_file_path);

fID_w = fopen([new_folder_path '/wave_elev' numToString100(last_saved_output+1) '.bin'],'w');
fwrite(fID_w,total_wave_serie,'double');

fID_str = fopen([new_folder_path '/stroke' numToString100(last_saved_output+1) '.bin'],'w');
fwrite(fID_str,s,'double');

if(max(abs(s))>290)
    fclose('all');
    error('max piston stroke > 290mm');
end  

fclose('all');
