%% Gumbel

% Objective: Gumbel analysis, finding the maximum value for the specified 
% quantile

% Method: Using formulae from [Naess and Moan, 2012]
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   vec_max     double [-]          vector of maxima
%   quantile    double [-]          specified quantile

%   Output      Type/Dimension      Description
%   x           double              max. value (F or M) for spec. quantile
%%
function [x] = Gumbel(vec_max,quantile)

vec_max = sort(vec_max);
s = size(vec_max,1)+1;
X = 1/s:1/s:1-1/s;
p = polyfit(vec_max',-log(-log(X)),1);
    
a = 1/p(1);
b = -p(2)*a;
  
x=b-a*log(log(1/quantile)); %max value for specified quantile
end