%% GumbelAnalyze

% Objective: Gumbel analysis, finding the maximum value for the specified 
% quantile and the p1 and p2 of the regression line y=p1*x+p2

% Method: Using formulae from [Naess and Moan, 2012]
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   vec_max     double [-]          vector of maxima
%   quantile    double [-]          specified quantile

%   Output      Type/Dimension      Description
%   x           double              max. value (F or M) for spec. quantile
%   p1          double              in the Gumbel regression line: p1*x+p2
%   p2           double              in the Gumbel regression line: p1*x+p2
%%
function [x,p1,p2] = GumbelAnalyze(vec_max,quantile)

vec_max = sort(vec_max);
s = length(vec_max)+1;
X = 1/s:1/s:1-1/s;
p = polyfit(vec_max,-log(-log(X)),1);
    
p1 = p(1);
p2 = p(2);

a = 1/p1;
b = -p2*a;
  
%max value for the specified quantile
x=b-a*log(log(1/quantile));
end