%% IntegrateAcceleration

% Objective: Finding the pile top position time histories from the 
% accelerometer measurements

% Method: Using a highpass filter and integrating twice
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   t           double [s]          time vector
%   acc         double [m/s^2]      measured pile top accelerations
%   cutoff      double [Hz]         filtering cut-off

%   Output      Type/Dimension      Description
%   pos         vector [m]          vector of pile top positions
%%
function [pos] = IntegrateAcceleration(t,acc,cutoff)
dt = (t(2)-t(1));
fs = 1/dt;
[b,a] = butter(5,cutoff*2/fs,'high');

acc_filtered = filter(b,a,acc);
vel = cumsum(acc_filtered)*dt;
vel_filtered = filter(b,a,vel);
pos = cumsum(vel_filtered)*dt;

end

