%%   IrregWaveSeries

% Objective: Generating the irregular output file which is input for
% CreateBatch.m
% Method: Calculating the JONSWAP peakedness factor gamma and executing
% Realize.m

% Last Modified: 04.2015
% Authors: Loup and Joakim

%   Output
%   wave_elev_Hs_Tp_seed_h.txt
%%
function [] = IrregWaveSeries()
clear all
close all
clc

% INPUT PARAMETERS
lambda=48;                       %scaling factor [-]
Tp_scal=[11.25]/sqrt(lambda);    %vector of peak periods [s]
h=30/lambda;                     %water depth [m]
Hs = [7.69]./lambda;             %vector of significant wave heights [m]
g = 9.81;                        %gravitational acceleration [m/s^2]
dt=1/50;                         %time step [s]. The wave maker operates with 50 Hz.
ramp=150;                        %ramp duration [s]
Tmax=3*3600/sqrt(lambda)+2*ramp; %time duration [s]
allseeds = [1:20];               %specify the number of seeds for each sea state (each seed is a function of the significant wave height, see below)

counter = 0;
for i = 1:length(Hs)
   hs = Hs(i);
   tp = Tp_scal(i);
   seeds = allseeds*floor(1000*hs);
   for j = seeds
       
       ID = [num2str(hs*lambda) 'm_' num2str(tp*sqrt(lambda)) 's_' num2str(j) '_h' num2str(h*lambda)];       
       
       % Creating wave time series
       gamma=42.2*(2*pi*hs/(g*tp^2))^(6/7);        %formula found in [Mathiesen et al., 2014]
       fprintf('The input significant wave height [m], Hs = %f \n', hs)
       [t,x] = Realize(Tmax,dt,hs,tp,gamma,h,g,j);
       
        name_w = ['wave_elev_' ID '.txt'];
        
        %inserting the ramp to the wave elevation
        for q=1:ramp/dt
            x(q)=x(q)*q/(ramp/dt);
            x(end-q+1)=x(end-q+1)*q/(ramp/dt);
        end
        
        %placing the resulting .txt file in the specified folder
        Tw=table(t',x');
        filepath_zeta = ['/Users/JoakimFrimann-Dahl/Documents/MATLAB/Master_matlab/Data/TestZeta/' name_w];
        writetable(Tw,filepath_zeta);

        counter = counter+1;
        disp([num2str(100*counter/((length(Hs)*length(seeds)))) '%'])

   end
end

end