%% JONSWAP_spectrum

% Objective: Generating a JONSWAP spectrum
% Method: Taking in the peakedness factor gamma to be multiplies with the
% PM spectrum

% Last Modified: 02.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   w           vector [rad/s]      contains the wave angular frequencies
%   Hs          double [m]          significant wave height
%   Tp          double [s]          spectral peak period
%   gamma       double [-]          peak enhancement factor

%   Output      Type/Dimension     Description
%   JSWP        vector             amplitude of the frequency components of w
%%
function [JSWP] = JONSWAP_spectrum(w,Hs,Tp,gamma)

wp = 2*pi/Tp;
i1 = find(w>wp,1);

% the values 0.07 and 0.09 specified in DNV-OS-J101
sigma = [(zeros(1,i1-1)+0.07) (zeros(1,length(w)-i1+1)+0.09)];

A = 1-0.287*log(gamma);
JSWP = A * PiersonMoskowitz_spectrum(w,Hs,Tp, cutoff) .* gamma.^(exp(-.5.*((w-wp)./(sigma.*wp)).^2));

end