%% PiersonMoskowitz_spectrum

% Objective: Generating a Pierson-Moskowitz spectrum
% Method: Using the formula specified in DNV-OS-J101
% Last Modified: 02.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   w           vector [rad/s]      contains the wave angular frequencies
%   Hs          double [m]          significant wave height
%   Tp          double [s]          spectral peak period

%   Output      Type/Dimension     Description
%   PM          vector             amplitude of the frequency components of w
%%
function [PM] = PiersonMoskowitz_spectrum(w,Hs,Tp)

% spectral peak frequency
wp = 2*pi/Tp;
cutoff = 0;

i2 = [];
if cutoff ~=0
    i2 = find(w>cutoff);
end

PM = (5/16)*Hs.^2*wp.^4.*w.^(-5).*exp((-5/4).*(w/wp).^(-4));
PM(i2) = 0;
end
