%% PlotHsTpGraph

% Objective: To plot the contour lines for the Dogger Bank, Creyke Beck B, 
% location 2

% Method: Using the values and formulae of [Mathiesen et al., 2014] through
% CalcHsTpProbability.m.

% Last Modified: 02.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   Hs_marker   vector [m]          Hs values to be marked in the plot
%   h           double [h]          water depth
%%
function []=PlotHsTpGraph(Hs_marker,h)

%Tp values to be marked in the plot
Tp_marker1=11.25;
Tp_marker2=15;

%axis ranges
hs = 0.01:.1:15;
tp = 0.01:.1:28;

%gravitational acceleration
g = 9.81;

%calculating sea state probabilities using CalcHsTpProbability.m
p = zeros(length(hs),length(tp));
for i = 1:length(hs)
   for j = 1:length(tp)
      p(i,j) = CalcHsTpProbability(hs(i),tp(j));
   end
end

%specifying return periods to be plotted
return_period = [10 50 100 1000 10000];
prob = (1/2922)./return_period;

figure(3)
contour(tp,hs,p,prob)
xlabel('Tp [s]');
ylabel('Hs [m]');
title(['Contour plot for water depth ', num2str(h), ' m']);
axis tight
grid

%plotting breaking limits based on linear wave theory (used to find the
%wave number k)
kh=[];
X=[];
for i = 1:length(tp)
    counter=1;
    A=4*pi^2*h/(g*tp(i)^2);
    X(counter)=sqrt(A);
    delta_kh=1;
    while delta_kh > 0.01
        X(counter+1)=X(counter)-(X(counter)*tanh(X(counter))-A)/(tanh(X(counter))+X(counter)*(sech(X(counter)))^2);
        delta_kh=abs(X(counter+1)-X(counter));
        counter=counter+1;
    end
    kh(i)=X(counter);
    X=[];
end
hold on
plot(tp,0.142*2*pi./kh*h.*tanh(kh))
hold on
plot(tp,0.1*2*pi./kh*h.*tanh(kh))
hold on
plot(tp,0.05*2*pi./kh*h.*tanh(kh))

%marking Hs, Tp combinations
t_mark1=[Tp_marker1 Tp_marker1];
t_mark2=[Tp_marker2 Tp_marker2];
hs_mark=[0 hs(end)];
t_marker1=Tp_marker1*ones(1,length(Hs_marker));
t_marker2=Tp_marker2*ones(1,length(Hs_marker));
hold on
plot(t_mark1,hs_mark,'r',t_marker1,Hs_marker,'r*')
hold on
plot(t_mark2,hs_mark,'r',t_marker2,Hs_marker,'r*')

xlim([0 tp(end)]);
ylim([0 hs(end)]);
