%% damping

% Objective: To find the linear and nonlinear damping coefficients as well 
% as the damping ratio using measurements from a decay test

% Method: Using the logarithmic decrement method of [Steen, 2014]
% Last Modified: 05.2015
% Authors: Loup and Joakim

%   Input
%   9000_decay_test_#.bin

%   Output      Type/Dimension      Description
%   p1          display to screen   linear damping coefficient
%   p2          display to screen   nonlinear damping coefficient
%   zeta_c      display to screen   damping ratio
%%
[a,b] = catman_read('/Volumes/MacintoshHD1/RunsOrganized/Decay/9000_decay_test_002.bin');
t = b(1).data(:);
yData = b(37).data(:); %moment My (x-direction)
%yData = b(32).data(:); %acceleration accx (x-direction)
%yData = b(33).data(:); %acceleration accy (y-direction)

figure;
plot(yData)
lowCutoff = input('Insert minimum cutoff: ');
highCutoff = input('Insert maximum cutoff: ');
close all
t=t(lowCutoff:highCutoff);
yData=yData(lowCutoff:highCutoff);
dt=t(2)-t(1);
counter=1;
%Finding the upcrossings
for ii=1:length(yData)-1
    if yData(ii)<0 && yData(ii+1)>0
        upCrossing(counter)=ii;
        counter=counter+1;
    end
end
findMax=[];
maxPos=[];
counter=1;
%Finding the maxima and their positions within each upcrossing
for ii=1:length(upCrossing)-1
    findMax(counter)=max(yData(upCrossing(ii):upCrossing(ii+1)));
    maxPos(counter)=find(yData(upCrossing(ii):upCrossing(ii+1))==findMax(counter))*dt+t(1)+upCrossing(ii)*dt;
    counter=counter+1;
end
ksi=[];
meanA=[];
T1vec=[];
%Finding the logarithmic decrement
for ii=1:length(findMax)-1
    ksi(ii)=log(findMax(ii)/findMax(ii+1))/(2*pi); %valid for lowly damped structures only
    meanA(ii)=(findMax(ii)+findMax(ii+1))/2;
    T1vec(ii)=maxPos(ii+1)-maxPos(ii);
    ratio(ii)=findMax(ii)/findMax(ii+1);
end
logmean_ratio=log(mean(ratio));
zeta_c=1/(sqrt(1+(2*pi/logmean_ratio)^2));
[A,B]=polyfit(meanA,ksi,1);
R=corrcoef(meanA,ksi);
R2=R(1,2)^2;
linreg=A(1)*meanA+A(2);
T1=mean(T1vec);
figure;
plot(t,yData,'b',maxPos,findMax,'or')
xlabel('t [s]')
figure;
plot(meanA,ksi)
hold on
plot(meanA,linreg)
xl=xlabel('Mean amplitude');
yl=ylabel('Logarithmic decrement');
set(xl,'FontSize',18);
set(yl,'FontSize',18);
fprintf('The first mode eigenperiod [s] is %f \n', T1);
fprintf('The linear damping parameter p1 is %f \n', A(2));
fprintf('The nonlinear damping parameter p2 is %f \n', A(1));
fprintf('p1/p2=%f \n', A(2)/A(1));
fprintf('zeta_c=%f \n', zeta_c);