%% findk

% Objective: To find the wave number k using linear wave theory 
% Method: Using an iterative procedure to find k on a finite water depth
% Last Modified: 03.2015
% Authors: Loup and Joakim

%   Input       Type/Dimension      Description
%   T           double [s]          wave period
%   h           double [m]          water depth

%   Output      Type/Dimension      Description
%   k           double [rad/m]      wave number
%%
function [k]=findk(T,h)

g=9.81;     %gravitational acceleration [m/s^2]

A=4*pi^2*h/(g*T^2);
X=[];
X(1)=sqrt(A);   %starting value for iteration
delta_kh=1;     %starting value for kh before iteration
counter=1;
while delta_kh > 0.01       %error limit of the wave number
    X(counter+1)=X(counter)-(X(counter)*tanh(X(counter))-A)/(tanh(X(counter))+X(counter)*(sech(X(counter)))^2);
    delta_kh=abs(X(counter+1)-X(counter));
    counter=counter+1;
end
kh=X(counter);
k=kh/h;
end