%% findk2

% Objective: To find the wave number k for a vector of wave frequencies
% using linear wave theory 

% Method: Using an iterative procedure to find k on a finite water depth
% Last Modified: 03.2015
% Authors: Joergen Krokstad

%   Input       Type/Dimension      Description
%   w           vector [rad/s]      wave frequencies
%   h           double [m]          water depth

%   Output      Type/Dimension      Description
%   k           vector [rad/m]      wave numbers

function [k]=findk2(w,h)
g = 9.81;

T=2*pi./w;
lambda=(g/(2*pi)*T.^2);
feilmargin=0.000001*ones(1,length(T));
feil=feilmargin+100;
while feil>=feilmargin
lambda_ny=1/2*lambda*g.*T.^2.*(-2*pi*h+2*pi*h.*tanh(2*pi*h./lambda).^2 ...
         -lambda.*tanh(2*pi*h./lambda))./...
         (pi*(-g*T.^2*h+g*T.^2*h.*tanh(2*pi*h./lambda).^2-lambda.^2));
   feil=abs(lambda_ny-lambda)./lambda;
   lambda=lambda_ny;
end;
k = 2*pi./lambda;

end